@@ -137,9 +137,6 @@ var localNewCmd = &console.Command{
 		if symfonyVersion != "" && c.Bool("demo") {
 			return console.Exit("The --version flag is not supported for the Symfony Demo", 1)
 		}
-		if c.Bool("webapp") && c.Bool("no-git") {
-			return console.Exit("The --webapp flag cannot be used with --no-git", 1)
-		}
 		if c.Bool("webapp") && c.Bool("api") {
 			return console.Exit("The --api flag cannot be used with --webapp", 1)
 		}
@@ -147,6 +144,9 @@ var localNewCmd = &console.Command{
 		if len(c.StringSlice("service")) > 0 && !withCloud {
 			return console.Exit("The --service flag cannot be used without --cloud or --upsun", 1)
 		}
+		if withCloud && c.Bool("no-git") {
+			return console.Exit("The --no-git flag cannot be used with --cloud or --upsun", 1)
+		}
 
 		s := terminal.NewSpinner(terminal.Stderr)
 		s.Start()
@@ -178,11 +178,12 @@ var localNewCmd = &console.Command{
 		if c.Bool("webapp") {
 			if err := runComposer(c, dir, []string{"require", "webapp"}, c.Bool("debug")); err != nil {
 				return err
-			}
-			buf, err := git.AddAndCommit(dir, []string{"."}, "Add webapp packages", c.Bool("debug"))
-			if err != nil {
-				fmt.Print(buf.String())
-				return err
+			} else if !c.Bool("no-git") {
+				buf, err := git.AddAndCommit(dir, []string{"."}, "Add webapp packages", c.Bool("debug"))
+				if err != nil {
+					fmt.Print(buf.String())
+					return err
+				}
 			}
 		}
 
