@@ -23,7 +23,6 @@ import (
 	"bytes"
 	"context"
 	"fmt"
-	"net"
 	"net/url"
 	"os"
 	"path/filepath"
@@ -69,17 +68,7 @@ func (l *Local) RelationshipsFromDocker() Relationships {
 		return nil
 	}
 
-	opts := [](docker.Opt){docker.FromEnv}
-	if host := os.Getenv(docker.EnvOverrideHost); host != "" && !strings.HasPrefix(host, "unix://") {
-		// Setting a dialer on top of a unix socket breaks the connection
-		// as the client then tries to connect to http:///path/to/socket and
-		// thus tries to resolve the /path/to/socket host
-		dialer := &net.Dialer{
-			Timeout: 2 * time.Second,
-		}
-		opts = append(opts, docker.WithDialContext(dialer.DialContext))
-	}
-	client, err := docker.NewClientWithOpts(opts...)
+	client, err := docker.NewClientWithOpts(docker.WithTimeout(2*time.Second), docker.FromEnv, dockerUseDesktopSocketIfAvailable)
 	if err != nil {
 		if l.Debug {
 			fmt.Fprintf(os.Stderr, "ERROR: %s\n", err)
@@ -94,7 +83,8 @@ func (l *Local) RelationshipsFromDocker() Relationships {
 	if err != nil {
 		if docker.IsErrConnectionFailed(err) {
 			terminal.Logger.Warn().Msg(err.Error())
-		} else if l.Debug {
+		}
+		if l.Debug {
 			fmt.Fprintf(os.Stderr, "ERROR: %s\n", err)
 		}
 		return nil
@@ -473,6 +463,24 @@ func formatDockerPort(port uint16) string {
 	return strconv.FormatInt(int64(port), 10)
 }
 
+func dockerUseDesktopSocketIfAvailable(c *docker.Client) error {
+	if c.DaemonHost() != docker.DefaultDockerHost {
+		return nil
+	}
+
+	homeDir, err := os.UserHomeDir()
+	if err != nil {
+		return err
+	}
+
+	socketPath := filepath.Join(homeDir, ".docker/run/docker.sock")
+	if _, err := os.Stat(socketPath); err != nil {
+		return nil
+	}
+
+	return docker.WithHost(`unix://` + socketPath)(c)
+}
+
 func getEnvValue(env string, key string) string {
 	if len(key) == len(env) {
 		return ""
