@@ -23,11 +23,9 @@ package main
 
 import (
 	"fmt"
-	"io"
 	"os"
 	"time"
 
-	"github.com/rs/zerolog"
 	"github.com/symfony-cli/console"
 	"github.com/symfony-cli/symfony-cli/commands"
 	"github.com/symfony-cli/symfony-cli/local/php"
@@ -52,6 +50,10 @@ func getCliExtraEnv() []string {
 }
 
 func main() {
+	if os.Getenv("SC_DEBUG") == "1" {
+		terminal.SetLogLevel(5)
+	}
+
 	args := os.Args
 	name := console.CurrentBinaryName()
 	// called via "php"?
@@ -71,20 +73,14 @@ func main() {
 	}
 	// called via "symfony console"?
 	if len(args) >= 2 && args[1] == "console" {
-		args[1] = "bin/console"
-		if _, err := os.Stat("app/console"); err == nil {
-			args[1] = "app/console"
+		if executor, err := php.SymonyConsoleExecutor(args[2:]); err == nil {
+			executor.ExtraEnv = getCliExtraEnv()
+			os.Exit(executor.Execute(false))
 		}
-		e := &php.Executor{
-			BinName:  "php",
-			Args:     args,
-			ExtraEnv: getCliExtraEnv(),
-		}
-		os.Exit(e.Execute(false))
 	}
 	// called via "symfony composer"?
 	if len(args) >= 2 && args[1] == "composer" {
-		res := php.Composer("", args[2:], getCliExtraEnv(), os.Stdout, os.Stderr, io.Discard, zerolog.Nop())
+		res := php.Composer("", args[2:], getCliExtraEnv(), os.Stdout, os.Stderr, os.Stderr, terminal.Logger)
 		terminal.Eprintln(res.Error())
 		os.Exit(res.ExitCode())
 	}
